@@ -1,12 +1,19 @@
+from typing import TYPE_CHECKING, Any
+
 from .base import ObjectBase
 
+if TYPE_CHECKING:
+    from ..client import Client
+    from ..resources import CustomerMandates
+
 
 class Mandate(ObjectBase):
     @classmethod
-    def get_resource_class(cls, client):
-        from ..resources.customer_mandates import CustomerMandates
+    def get_resource_class(cls, client: "Client", **kwargs: Any) -> "CustomerMandates":
+        from ..resources import CustomerMandates
 
-        return CustomerMandates(client)
+        customer = kwargs["customer"]
+        return CustomerMandates(client, customer)
 
     STATUS_PENDING = "pending"
     STATUS_VALID = "valid"
@@ -56,8 +63,7 @@ class Mandate(ObjectBase):
         """Check if the mandate is invalid."""
         return self.status == self.STATUS_INVALID
 
-    @property
-    def customer(self):
+    def get_customer(self):
         """Return the customer for this mandate."""
         url = self._get_link("customer")
         if url:
