@@ -49,9 +49,9 @@ class PaymentRefunds(RefundsBase, ResourceCreateMixin, ResourceDeleteMixin, Reso
         self.validate_resource_id(resource_id, "Refund ID")
         return super().get(resource_id, **params)
 
-    def delete(self, resource_id: str, **params: Any) -> dict:
+    def delete(self, resource_id: str, idempotency_key: str = "", **params: Any) -> dict:
         self.validate_resource_id(resource_id, "Refund ID")
-        return super().delete(resource_id, **params)
+        return super().delete(resource_id, idempotency_key, **params)
 
 
 class OrderRefunds(RefundsBase, ResourceCreateMixin, ResourceListMixin):
@@ -66,11 +66,11 @@ class OrderRefunds(RefundsBase, ResourceCreateMixin, ResourceListMixin):
     def get_resource_path(self) -> str:
         return f"orders/{self._order.id}/refunds"
 
-    def create(self, data: Optional[Dict[str, Any]] = None, **params: Any) -> Refund:
+    def create(self, data: Optional[Dict[str, Any]] = None, idempotency_key: str = "", **params: Any) -> Refund:
         """Create a refund for the order. When no data arg is given, a refund for all order lines is assumed."""
         if not data:
             data = {"lines": []}
-        return super().create(data, **params)
+        return super().create(data, idempotency_key, **params)
 
 
 class SettlementRefunds(RefundsBase, ResourceListMixin):
